Supabase class
Constructors
- Supabase()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ SupabaseClient
-
latefinal
Static Methods
-
db<
T extends TableRow> () → SupabaseRepository< T> ? -
initialize(
{required String supabaseUrl, required String supabaseAnonKey}) → void -
register<
T extends TableRow> (dynamic tableAccessor, SupabaseRepository< T> instance) → void